KlarnaPostPurchaseError class

Inheritance

Constructors

KlarnaPostPurchaseError(String name, String message, String? status, bool isFatal)

Properties

hashCode int
The hash code for this object.
no setterinherited
isFatal bool
finalinherited
message String
finalinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited